==> mono_1.9.1+dfsg.orig.tar.gz: mono-1.9.1+dfsg/mcs/class/Managed.Windows.Forms/System.Windows.Forms/DataGridViewCellParsingEventArgs.cs <==
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (c) 2005 Novell, Inc. (http://www.novell.com)
//
// Author:
//	Pedro Martínez Juliá <pedromj@gmail.com>
//


#if NET_2_0

namespace System.Windows.Forms {

	public class DataGridViewCellParsingEventArgs : ConvertEventArgs {

		private int columnIndex;
		private DataGridViewCellStyle inheritedCellStyle;
		private bool parsingApplied = false;
		private int rowIndex;

		public DataGridViewCellParsingEventArgs (int columnIndex, int rowIndex, object value, Type desiredType, DataGridViewCellStyle inheritedCellStyle) : base (value, desiredType) {
			this.columnIndex = columnIndex;
			this.rowIndex = rowIndex;
			this.inheritedCellStyle = inheritedCellStyle;
		}

		public DataGridViewCellStyle InheritedCellStyle {
			get { return inheritedCellStyle; }
			set { inheritedCellStyle = value; }
		}

		public int ColumnIndex {
			get { return columnIndex; }
		}

		public bool ParsingApplied {
			get { return parsingApplied; }
			set { parsingApplied = value; }
		}

		public int RowIndex {
			get { return rowIndex; }
		}

	}

}

#endif

==> mono_2.6.7.orig.tar.gz: mono-2.6.7/mcs/class/Managed.Windows.Forms/System.Windows.Forms/DataGridViewCellParsingEventArgs.cs <==
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (c) 2005 Novell, Inc. (http://www.novell.com)
//
// Author:
//	Pedro Martínez Juliá <pedromj@gmail.com>
//


#if NET_2_0

namespace System.Windows.Forms {

	public class DataGridViewCellParsingEventArgs : ConvertEventArgs {

		private int columnIndex;
		private DataGridViewCellStyle inheritedCellStyle;
		private bool parsingApplied = false;
		private int rowIndex;

		public DataGridViewCellParsingEventArgs (int rowIndex, int columnIndex, object value, Type desiredType, DataGridViewCellStyle inheritedCellStyle)
			: base (value, desiredType)
		{
			this.columnIndex = columnIndex;
			this.rowIndex = rowIndex;
			this.inheritedCellStyle = inheritedCellStyle;
		}

		public DataGridViewCellStyle InheritedCellStyle {
			get { return inheritedCellStyle; }
			set { inheritedCellStyle = value; }
		}

		public int ColumnIndex {
			get { return columnIndex; }
		}

		public bool ParsingApplied {
			get { return parsingApplied; }
			set { parsingApplied = value; }
		}

		public int RowIndex {
			get { return rowIndex; }
		}

	}

}

#endif
